@@ -1,10 +1,10 @@
-# $Rev: 681 $
+# $Rev: 682 $
 package Date::ICal;
 use strict;
 use warnings;
 
 use vars qw($VERSION $localzone $localoffset @months @leapmonths %add_units);
-$VERSION = '2.'.(qw'$Rev: 681 $')[1];
+$VERSION = '2.'.(qw'$Rev: 682 $')[1];
 use Carp;
 use Time::Local;
 use Date::Leapyear qw();
@@ -27,7 +27,7 @@ Date::ICal - Perl extension for ICalendar date objects.
 
 =head1 VERSION
 
-$Revision: 681 $
+$Revision: 682 $
 
 =head1 SYNOPSIS
 
@@ -1289,9 +1289,9 @@ datetime@perl.org mailing list
 
 L<https://github.com/houseabsolute/DateTime.pm/wiki>
 
-Time::Local
+L<Time::Local>
 
-Net::ICal
+L<Net::ICal>
 
 =cut
 
